Handling data
=============

.. image:: ../../images/diagram_volumes.svg
   :alt: Training with volumes

.. image:: ../../images/diagram_patches.svg
   :alt: Training with patches


.. toctree::
   :maxdepth: 3

   images.rst
   patch_based.rst
